Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(277)

Unified Diff: third_party/WebKit/Source/core/paint/PartPainter.cpp

Issue 2723993002: Rename platform/Widget to platform/FrameViewBase in core. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/paint/PartPainter.cpp
diff --git a/third_party/WebKit/Source/core/paint/PartPainter.cpp b/third_party/WebKit/Source/core/paint/PartPainter.cpp
index e7f27a1683c6268c0cded4998a1ded3d90b40511..9f31767fb65caa85079358ffb50383e11f4bd648 100644
--- a/third_party/WebKit/Source/core/paint/PartPainter.cpp
+++ b/third_party/WebKit/Source/core/paint/PartPainter.cpp
@@ -118,23 +118,24 @@ void PartPainter::paintContents(const PaintInfo& paintInfo,
const LayoutPoint& paintOffset) {
LayoutPoint adjustedPaintOffset = paintOffset + m_layoutPart.location();
- Widget* widget = m_layoutPart.widget();
- CHECK(widget);
+ FrameViewBase* frameViewBase = m_layoutPart.widget();
+ CHECK(frameViewBase);
IntPoint paintLocation(roundedIntPoint(
adjustedPaintOffset + m_layoutPart.replacedContentRect().location()));
- // Widgets don't support painting with a paint offset, but instead offset
- // themselves using the frame rect location. To paint widgets at our desired
- // location, we need to apply paint offset as a transform, with the frame rect
- // neutralized.
- IntSize widgetPaintOffset = paintLocation - widget->frameRect().location();
+ // FrameViewBases don't support painting with a paint offset, but instead
+ // offset themselves using the frame rect location. To paint widgets at our
+ // desired location, we need to apply paint offset as a transform, with the
+ // frame rect neutralized.
+ IntSize widgetPaintOffset =
+ paintLocation - frameViewBase->frameRect().location();
TransformRecorder transform(
paintInfo.context, m_layoutPart,
AffineTransform::translation(widgetPaintOffset.width(),
widgetPaintOffset.height()));
CullRect adjustedCullRect(paintInfo.cullRect(), -widgetPaintOffset);
- widget->paint(paintInfo.context, adjustedCullRect);
+ frameViewBase->paint(paintInfo.context, adjustedCullRect);
}
} // namespace blink

Powered by Google App Engine
This is Rietveld 408576698